# Changelog

All notable changes to this project will be documented in this file.

## [0.1.0] - 2023-12-20

### Documentation

- Explain the new environemnt variables to use external files

### Features

- Allow to use external files

### Miscellaneous Tasks

- Refactor - use isinstance

## [0.0.2] - 2023-06-27

### Bug Fixes

- Ignore types for geopandas
- Fix mpypy with typing all_dict

### Documentation

- Install instructions
- Cli usage
- Update usage
- Update docs with latest usage
- Document search multiple

### Features

- Module that resolve lat lng to streets or neighborhoods - WIP
- Support translations for streets
- Cli for streets
- Neighborhoods resolver
- Allow to search by name with CLI
- Resolve both streets and neighborhoods
- Can search by number
- Can search by street
- Can search by code
- Allow search multiples

### Miscellaneous Tasks

- Add geopandas as deps
- Include data file in the wheel
- Track dbf and shp files
- Data for latvia
- Read and parse address shp file
- Attributes are 'protected'
- Rename df to gdf
- Lower the case of all the strings
- More preprocessing
- Refactor - use read method
- Translations dict
- Remove resolve method
- Use str instead of int for values
- Language is also a str
- Drop row with nulls when reading
- Put the address in lowercase
- Use the double resolver for the CLI
- Add mypy as pre-commit
- Refactor - better match statement
- Tests for SteetsAndNeighborhoodsResolver
- Remove pyc file
- Basic gitignore file
- Ignore coverage file
- Remove code duplication
- Wrote an example of usage
- Bump to v0.0.2

### Build

- Can install cli optionally

### Ci

- Coverage in CI

## [unreleased]

### Bug Fixes

- Ignore types for geopandas
- Fix mpypy with typing all_dict

### Documentation

- Install instructions
- Cli usage
- Update usage
- Update docs with latest usage
- Document search multiple

### Features

- Module that resolve lat lng to streets or neighborhoods - WIP
- Support translations for streets
- Cli for streets
- Neighborhoods resolver
- Allow to search by name with CLI
- Resolve both streets and neighborhoods
- Can search by number
- Can search by street
- Can search by code
- Allow search multiples

### Miscellaneous Tasks

- Add geopandas as deps
- Include data file in the wheel
- Track dbf and shp files
- Data for latvia
- Read and parse address shp file
- Attributes are 'protected'
- Rename df to gdf
- Lower the case of all the strings
- More preprocessing
- Refactor - use read method
- Translations dict
- Remove resolve method
- Use str instead of int for values
- Language is also a str
- Drop row with nulls when reading
- Put the address in lowercase
- Use the double resolver for the CLI
- Add mypy as pre-commit
- Refactor - better match statement
- Tests for SteetsAndNeighborhoodsResolver
- Remove pyc file
- Basic gitignore file
- Ignore coverage file
- Remove code duplication
- Wrote an example of usage
- Bump to v0.0.2

### Build

- Can install cli optionally

### Ci

- Coverage in CI

## [0.0.1] - 2023-06-23

### Documentation

- Remove README boilerplat

### Miscellaneous Tasks

- Add license
- Cliff config file (for changelogs)
- More recent pre-commit
- Add pre-commit config file
- Initial almost empty module

### Build

- Initial pyproject file

### Ci

- Initial CI that can test and publish to pypi

<!-- generated by git-cliff -->
